package CPAN::Local::Role::Index;
{
  $CPAN::Local::Role::Index::VERSION = '0.006';
}

# ABSTRACT: Index a repo

use strict;
use warnings;

use Moose::Role;
use namespace::clean -except => 'meta';

requires 'index';

1;


__END__
=pod

=head1 NAME

CPAN::Local::Role::Index - Index a repo

=head1 VERSION

version 0.006

=head1 DESCRIPTION

Plugins implementing this role are executed as part of the update process,
after the distributions have been physically injected into the repository.

=head1 INTERFACE

Plugins implementing this role should provide a C<index> method with the
following interface:

=head2 Parameters

None.

=head2 Returns

List of L<CPAN::Local::Distribution> objects representing distributions that
need to be indexed.

=head1 AUTHOR

Peter Shangov <pshangov@yahoo.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Venda, Inc..

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

